package com.fg.scripting.exception;

/**
 * Exception is thrown when instance cannot be created upon specified class.
 *
 * @author Jan Novotný, FG Forrest a.s. (c) 2007
 * @version $Id: ClassInstantiationException.java,v 1.2 2009/11/15 20:05:12 u_novoj Exp $
 */
public class ClassInstantiationException extends RuntimeException {
	private static final long serialVersionUID = -1066268646675910119L;
	private final Class clazz;

	/**
	 * Constructs a new runtime exception with <code>null</code> as its
	 * detail message.  The cause is not initialized, and may subsequently be
	 * initialized by a call to {@link #initCause}.
	 */
	public ClassInstantiationException(Class clazz) {
		this.clazz = clazz;
	}

	/**
	 * Constructs a new runtime exception with the specified detail message.
	 * The cause is not initialized, and may subsequently be initialized by a
	 * call to {@link #initCause}.
	 *
	 * @param message the detail message. The detail message is saved for
	 *                later retrieval by the {@link #getMessage()} method.
	 */
	public ClassInstantiationException(String message, Class clazz) {
		super(message);
		this.clazz = clazz;
	}

	/**
	 * Constructs a new runtime exception with the specified detail message and
	 * cause.  <p>Note that the detail message associated with
	 * <code>cause</code> is <i>not</i> automatically incorporated in
	 * this runtime exception's detail message.
	 *
	 * @param message the detail message (which is saved for later retrieval
	 *                by the {@link #getMessage()} method).
	 * @param cause   the cause (which is saved for later retrieval by the
	 *                {@link #getCause()} method).  (A <tt>null</tt> value is
	 *                permitted, and indicates that the cause is nonexistent or
	 *                unknown.)
	 * @since 1.4
	 */
	public ClassInstantiationException(String message, Throwable cause, Class clazz) {
		super(message, cause);
		this.clazz = clazz;
	}

	/**
	 * Constructs a new runtime exception with the specified cause and a
	 * detail message of <tt>(cause==null ? null : cause.toString())</tt>
	 * (which typically contains the class and detail message of
	 * <tt>cause</tt>).  This constructor is useful for runtime exceptions
	 * that are little more than wrappers for other throwables.
	 *
	 * @param cause the cause (which is saved for later retrieval by the
	 *              {@link #getCause()} method).  (A <tt>null</tt> value is
	 *              permitted, and indicates that the cause is nonexistent or
	 *              unknown.)
	 * @since 1.4
	 */
	public ClassInstantiationException(Throwable cause, Class clazz) {
		super(cause);
		this.clazz = clazz;
	}

	/**
	 * Returns problematic class.
	 * @return
	 */
	public Class getClazz() {
		return clazz;
	}

}
