package com.fg.scripting.groovy.classloader;

import groovy.lang.GroovyClassLoader;
import org.codehaus.groovy.control.CompilationFailedException;
import org.codehaus.groovy.control.CompilerConfiguration;
import org.springframework.context.support.AbstractRefreshableApplicationContext;

import java.io.IOException;
import java.lang.ref.WeakReference;
import java.net.URL;

/**
 * Description
 *
 * @author Jan Novotný, FG Forrest a.s. (c) 2007
 * @version $Id: SpringContextRefreshingGroovyClassloader.java,v 1.3 2009/11/15 20:05:11 u_novoj Exp $
 */
@SuppressWarnings({"CustomClassloader"})
public class SpringContextRefreshingGroovyClassloader extends GroovyClassLoader {
	private final WeakReference<AbstractRefreshableApplicationContext> applicationContext;

	public SpringContextRefreshingGroovyClassloader(AbstractRefreshableApplicationContext applicationContext) {
		this.applicationContext = new WeakReference<AbstractRefreshableApplicationContext>(applicationContext);
	}

	public SpringContextRefreshingGroovyClassloader(ClassLoader loader, AbstractRefreshableApplicationContext applicationContext) {
		super(loader);
		this.applicationContext = new WeakReference<AbstractRefreshableApplicationContext>(applicationContext);
	}

	public SpringContextRefreshingGroovyClassloader(GroovyClassLoader parent, AbstractRefreshableApplicationContext applicationContext) {
		super(parent);
		this.applicationContext = new WeakReference<AbstractRefreshableApplicationContext>(applicationContext);
	}

	public SpringContextRefreshingGroovyClassloader(ClassLoader parent, CompilerConfiguration config, boolean useConfigurationClasspath, AbstractRefreshableApplicationContext applicationContext) {
		super(parent, config, useConfigurationClasspath);
		this.applicationContext = new WeakReference<AbstractRefreshableApplicationContext>(applicationContext);
	}

	public SpringContextRefreshingGroovyClassloader(ClassLoader loader, CompilerConfiguration config, AbstractRefreshableApplicationContext applicationContext) {
		super(loader, config);
		this.applicationContext = new WeakReference<AbstractRefreshableApplicationContext>(applicationContext);
	}

	@Override
	protected Class recompile(URL source, String className, Class oldClass) throws CompilationFailedException, IOException {
		if (source != null) {
            // found a source, compile it if newer
			if (oldClass == null) {				
                return parseClass(source.openStream(), className);
			} else if (isSourceNewer(source, oldClass)) {
                clearCache();
				applicationContext.get().refresh();
            }
        }
        return oldClass;
	}

}
